@@ -787,13 +787,13 @@ class _CodeInclude(Directive):
             )
         except UnicodeEncodeError:
             raise self.severe(
-                u'Problems with "%s" directive path:\n'
+                'Problems with "%s" directive path:\n'
                 'Cannot encode input file path "%s" '
                 "(wrong locale?)." % (self.name, SafeString(path))
             )
         except IOError as error:
             raise self.severe(
-                u'Problems with "%s" directive path:\n%s.'
+                'Problems with "%s" directive path:\n%s.'
                 % (self.name, ErrorString(error))
             )
         startline = self.options.get("start-line", None)
@@ -806,7 +806,7 @@ class _CodeInclude(Directive):
                 rawtext = include_file.read()
         except UnicodeError as error:
             raise self.severe(
-                u'Problem with "%s" directive:\n%s' % (self.name, ErrorString(error))
+                'Problem with "%s" directive:\n%s' % (self.name, ErrorString(error))
             )
         # start-after/end-before: no restrictions on newlines in match-text,
         # and no restrictions on matching inside lines vs. line boundaries
